var tabGroup = Ti.UI.createTabGroup({orientationModes: [Ti.UI.PORTRAIT]}),
winViews = Ti.UI.createWindow({
	title: "View Properties",
	layout: "vertical",
	backgroundColor: "#fff"
}),
winEvents = Ti.UI.createWindow({
	title: "Events",
	layout: "vertical",
	backgroundColor: "#fff"
}),
tabViews = Ti.UI.createTab({
	window: winViews,
	title: winViews.title
}),
tabEvents = Ti.UI.createTab({
	window: winEvents,
	title: winEvents.title
}),
announceButton = Ti.UI.createButton({
	top: 16, width: 8 * 30, height: 48,
	title: "Make announcement"
}),
basicButton = Ti.UI.createButton({
	top: 16, width: 8 * 14, height: 48,
	title: "Basic"
}),
differentButton = Ti.UI.createButton({
	top: 16, width: 8 * 14, height: 48,
	title: "Different",
	accessibilityLabel: "This has different text for accessibility."
}),
sw = Ti.UI.createSwitch({
	value: false,
	accessibilityLabel: "My special switch.",
	accessibilityValue: "Off.",
	accessibilityHint: "Double tap to turn on.",
	top: 16

}),
eventLog = Ti.UI.createLabel({
	top: 16, left: 32, right: 32,
	height: 48 * 5,
	verticalAlign: Ti.UI.TEXT_VERTICAL_ALIGNMENT_TOP,
	accessibilityHidden: true
}),
versionParts = Ti.Platform.version.split("."),
isJellyBeanOrBetter = (parseInt(versionParts[0] > 4) ||
					   (parseInt(versionParts[0]) == 4 && parseInt(versionParts[1]) > 0));

sw.on("change", function() {
	if (sw.value) {
		sw.accessibilityValue = "On.";
		sw.accessibilityHint = "Double tap to turn off."
	} else {
		sw.accessibilityValue = "Off.";
		sw.accessibilityHint = "Double tap to turn on."
	}
});

announceButton.on("click", function() {
	Ti.App.fireSystemEvent(Ti.App.EVENT_ACCESSIBILITY_ANNOUNCEMENT,
						   "Please stand by for an urgent message from the Department of Home Land Security.");
});

Ti.App.addEventListener(Ti.App.EVENT_ACCESSIBILITY_CHANGED, function(e) {
	eventLog.text += "\nAccessibility state changed: " + (e.enabled ? "it is now enabled." : "it is now disabled.");
});

eventLog.text = "This label has the accessibilityHidden property set to true. ";
eventLog.text += "This tells the accessibility service to ignore it. ";
if (!isJellyBeanOrBetter) {
	eventLog.text += "However, this only works on Android 4.1 (Jelly Bean) and higher and you are running Android " + Ti.Platform.version + ".";
}
eventLog.text += "\n\n";
eventLog.text += (Ti.App.accessibilityEnabled ? "Accessibility is enabled." : "Accessibility is disabled.");
if (parseInt(versionParts[0]) >= 4) {
	eventLog.text += "\n\nIf you go to Settings and disable/enable accessibility, the change will be reflected here.\n";
} else {
	eventLog.text += "\n\nOn Ice Cream Sandwich and higher devices, if you went to Settings and disabled/enabled ";
	eventLog.text += "accessibility, the change would be reflected here. But since you are running Android ";
	eventLog.text += Ti.Platform.version + ", you won't see that.";
}


winViews.add(basicButton);
winViews.add(differentButton);
winViews.add(sw);
winEvents.add(announceButton);
winEvents.add(eventLog);

tabGroup.addTab(tabViews);
tabGroup.addTab(tabEvents);
tabGroup.open();
